@@ -1,8 +1,10 @@
-use crate::board::board_test_main;
-use board_game::games::chess::ChessBoard;
-use board_game::board::Board;
 use chess::ChessMove;
 
+use board_game::board::Board;
+use board_game::games::chess::ChessBoard;
+
+use crate::board::board_test_main;
+
 #[test]
 fn chess_start() {
     board_test_main(&ChessBoard::default());
@@ -15,10 +17,10 @@ fn chess_en_passant() {
     let mut board = ChessBoard::default();
     for &mv in &moves {
         println!("{}", board);
-        board.play(ChessMove::from_san(&board.inner, mv).unwrap());
+        board.play(ChessMove::from_san(&board.inner(), mv).unwrap());
     }
 
-    let capture = ChessMove::from_san(&board.inner, "ed6").unwrap();
+    let capture = ChessMove::from_san(&board.inner(), "ed6").unwrap();
     assert!(board.is_available_move(capture));
 
     board_test_main(&board);
